@@ -41,3 +41,14 @@ def str_datetime(stamp):
 def now_time():
     """Get the current time."""
     return datetime.datetime.now()
+
+
+def valid_ip(query):
+    """Check if an IP address is valid."""
+    import socket
+
+    try:
+        socket.inet_aton(query)
+        return True
+    except socket.error:
+        return False
